summaryrefslogtreecommitdiffstats
path: root/kdesktop/bgmanager.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:46:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:46:05 -0600
commit73c08b592db45af554b9f21029bc549d70f683ab (patch)
tree122898ea951e59fdc4419b3c84b7a6c2dd0bb5f7 /kdesktop/bgmanager.cc
parente81bdee8ae92d6eeb82daa8c0a0e46bf37f4a6da (diff)
downloadtdebase-73c08b592db45af554b9f21029bc549d70f683ab.tar.gz
tdebase-73c08b592db45af554b9f21029bc549d70f683ab.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kdesktop/bgmanager.cc')
-rw-r--r--kdesktop/bgmanager.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdesktop/bgmanager.cc b/kdesktop/bgmanager.cc
index a643905eb..cf61030bb 100644
--- a/kdesktop/bgmanager.cc
+++ b/kdesktop/bgmanager.cc
@@ -518,11 +518,11 @@ void KBackgroundManager::setPixmap(KPixmap *pm, int hash, int desk)
{
TQScrollView* sv = dynamic_cast<TQScrollView*>( m_pDesktop );
if ( sv ) {
// Qt eats tqrepaint events in this case :-((
sv->viewport()->update();
}
m_pDesktop->setErasePixmap(*ep);
- m_pDesktop->tqrepaint();
+ m_pDesktop->repaint();
static bool root_cleared = false;
if( !root_cleared )
{ // clear the root window pixmap set by kdm
@@ -923,7 +923,7 @@ void KBackgroundManager::setWallpaper(int desk, TQString wallpaper, int mode)
void KBackgroundManager::repaintBackground()
{
if (m_pDesktop)
- m_pDesktop->tqrepaint();
+ m_pDesktop->repaint();
else
TQT_TQWIDGET(KApplication::desktop()->screen())->erase();
}
@@ -518,11 +518,11 @@ void KBackgroundManager::setPixmap(KPixmap *pm, int hash, int desk)
TQScrollView* sv = dynamic_cast<TQScrollView*>( m_pDesktop );
if ( sv ) {
- // Qt eats tqrepaint events in this case :-((
+ // Qt eats repaint events in this case :-((
sv->viewport()->update();
}